**************************************
LSQ Equation Construction and Solving
**************************************

.. moduleauthor:: Mihai Cara <help@stsci.edu>

.. currentmodule:: jwst.mrs_imatch.mrs_imatch_step

.. automodule:: jwst.mrs_imatch.mrs_imatch_step
   :members:
   :undoc-members:
